@@ -1,8 +1,12 @@
+
+
 use crate::security::*;
 use crate::types::interaction::*;
 use actix_web::http::StatusCode;
 use actix_web::{web, App, HttpRequest, HttpResponse, HttpServer, Result};
-use reqwest::Client;
+use reqwest::{Client};
+#[cfg(feature="extended-handler")]
+use reqwest::header;
 
 use log::{debug, error};
 
@@ -18,7 +22,8 @@ pub type HandlerResponse = InteractionResponse;
 type HandlerFunction = fn(Context) -> Pin<Box<dyn Future<Output = HandlerResponse> + Send>>;
 
 
-#[derive(Clone)]
+#[derive(Clone, Debug)]
+#[cfg(all(feature="handler", not(feature="extended-handler")))]
 /// The InteractionHandler is the 'thing' that will handle your incoming interactions.
 /// It does interaction validation (as required by Discord) and provides a pre-defined actix-web server
 /// with [`InteractionHandler::run`] and [`InteractionHandler::run_ssl`]
@@ -26,13 +31,26 @@ pub struct InteractionHandler {
     /// The public key of your application.
     pub app_public_key: PublicKey,
     client: Client,
-    /// Your bot token or bearer
-    //auth_key: &'static str,
+    // Might want to change this to use the command id rather than the name of the command: prone to duplicates.
+    handles: HashMap<&'static str, HandlerFunction>,
+}
+
+
+#[derive(Clone, Debug)]
+/// The InteractionHandler is the 'thing' that will handle your incoming interactions.
+/// It does interaction validation (as required by Discord) and provides a pre-defined actix-web server
+/// with [`InteractionHandler::run`] and [`InteractionHandler::run_ssl`]
+#[cfg(feature="extended-handler")]
+pub struct InteractionHandler {
+    /// The public key of your application.
+    pub app_public_key: PublicKey,
+    client: Client,
     // Might want to change this to use the command id rather than the name of the command: prone to duplicates.
     handles: HashMap<&'static str, HandlerFunction>,
 }
 
 impl InteractionHandler {
+    #[cfg(all(feature="handler", not(feature="extended-handler")))]
     /// Initalizes a new `InteractionHandler`
     pub fn new(pbk_str: &str) -> InteractionHandler {
         let pbk_bytes =
@@ -47,6 +65,27 @@ impl InteractionHandler {
             handles: HashMap::new(),
         }
     }
+    #[cfg(feature="extended-handler")]
+    /// Initalizes a new `InteractionHandler`
+    pub fn new(pbk_str: &str, token: &'static str) -> InteractionHandler {
+        let pbk_bytes =
+            hex::decode(pbk_str).expect("Failed to parse the public key from hexadecimal");
+
+        let app_public_key =
+            PublicKey::from_bytes(&pbk_bytes).expect("Failed to parse public key.");
+
+        let mut headers = header::HeaderMap::new();
+        let mut auth_value = header::HeaderValue::from_static(token);
+        auth_value.set_sensitive(true);
+        headers.insert(header::AUTHORIZATION, auth_value);
+        let new_c = Client::builder().default_headers(headers).build().unwrap();
+
+        InteractionHandler {
+            app_public_key,
+            client: new_c,
+            handles: HashMap::new(),
+        }
+    }
 
     /// Binds an async function to a command.
     /// Your function must take a [`Context`] as an argument and must return a [`InteractionResponse`].
@@ -225,8 +264,12 @@ impl InteractionHandler {
         .run()
         .await
     }
+
+    
 }
 
+
+
 /// Simpler header getter from a HTTP request
 fn get_header<'a>(req: &'a HttpRequest, header: &str) -> Option<&'a str> {
     req.headers().get(header)?.to_str().ok()
