@@ -16,7 +16,8 @@ use ed25519_dalek::PublicKey;
 ];*/
 
 const TEST_PUB_KEY: &str = "82d8d97fe0641e68a1b0b11220f05e9ea0539a0cdc002119d4a9e9e025aba1e9";
-
+#[cfg(feature="extended-handler")]
+const EMPTY_TOKEN: &str = "";
 /*------------------------------
 SECURITY TESTS
 */
@@ -89,12 +90,27 @@ macro_rules! interaction_app_init {
         .await;
     };
 }
+#[cfg(all(feature="handler", not(feature="extended-handler")))]
+macro_rules! init_handler{
+    () => {
+        
+        InteractionHandler::new(TEST_PUB_KEY)
+    };
+}
+
+#[cfg(feature="extended-handler")]
+macro_rules! init_handler{
+    () => {
+        
+        InteractionHandler::new(TEST_PUB_KEY, EMPTY_TOKEN)
+    };
+}
 
 #[actix_rt::test]
 // Request with bad content with no Content-Type header present
 // Expected result: Return 400 without panicking
 async fn interactions_no_content_type_header_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -112,7 +128,7 @@ async fn interactions_no_content_type_header_test() {
 // Request with bad content with no Content-Type header present
 // Expected result: Return 400 without panicking
 async fn interactions_bad_content_type_header_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -131,7 +147,7 @@ async fn interactions_bad_content_type_header_test() {
 // Request with missing X-Signature-Ed25519 Header
 // Expected result: Return 400 without panicking
 async fn interactions_no_signature_header_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -151,7 +167,7 @@ async fn interactions_no_signature_header_test() {
 // Request with missing X-Signature-Timestamp Header
 // Expected result: Return 400 without panicking
 async fn interactions_no_timestamp_header_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -171,7 +187,7 @@ async fn interactions_no_timestamp_header_test() {
 // Request with missing a signature that is too short (< 512 bits)
 // Expected result: Return 400 without panicking
 async fn interactions_bad_signature_length_short_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -194,7 +210,7 @@ async fn interactions_bad_signature_length_short_test() {
 // Request with missing a signature that is too long (> 512 bits)
 // Expected result: Return 400 without panicking
 async fn interactions_bad_signature_length_too_long_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -214,7 +230,7 @@ async fn interactions_bad_signature_length_too_long_test() {
 // Normal ping request
 // Expected result: Return 200 with payload
 async fn interactions_ping_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -239,7 +255,7 @@ async fn interactions_ping_test() {
 // Bad content but OK signature test
 // Expected result: Return 400 with error, don't panic
 async fn interactions_bad_body_test() {
-    let ih = InteractionHandler::new(TEST_PUB_KEY);
+    let ih = init_handler!();
 
     let mut app = interaction_app_init!(ih);
 
@@ -274,7 +290,7 @@ async fn normal_handle_direct_test(_: Context) -> InteractionResponse {
 
 #[actix_rt::test]
 async fn interactions_normal_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", normal_handle_test);
 
@@ -302,7 +318,7 @@ async fn interactions_normal_handle_test() {
 
 #[actix_rt::test]
 async fn interactions_normal_from_value_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", normal_handle_direct_test);
 
@@ -330,7 +346,7 @@ async fn interactions_normal_from_value_handle_test() {
 
 #[actix_rt::test]
 async fn interactions_normal_from_direct_call_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", normal_handle_value_test);
 
@@ -380,7 +396,7 @@ async fn deffered_handle_direct_test(_ctx: Context) -> InteractionResponse {
 
 #[actix_rt::test]
 async fn interactions_deffered_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", deffered_handle_test);
 
@@ -409,7 +425,7 @@ async fn interactions_deffered_handle_test() {
 
 #[actix_rt::test]
 async fn interactions_deffered_from_value_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", deffered_handle_value_test);
 
@@ -438,7 +454,7 @@ async fn interactions_deffered_from_value_handle_test() {
 
 #[actix_rt::test]
 async fn interactions_deffered_from_direct_value_handle_test() {
-    let mut ih = InteractionHandler::new(TEST_PUB_KEY);
+    let mut ih = init_handler!();
 
     ih.add_command("test", deffered_handle_direct_test);
 
