@@ -1,3 +1,8 @@
+use crate::{expect_specific_api_response, expect_successful_api_response};
+#[cfg(feature="extended-handler")]
+use crate::{expect_successful_api_response_and_return};
+
+
 use serde::{Deserialize, Serialize};
 
 use serde_with::*;
@@ -6,83 +11,27 @@ use serde_repr::*;
 
 use super::application::*;
 use super::embed::*;
+#[cfg(feature="extended-handler")]
+use super::guild::*;
 use super::user::*;
 use super::HttpError;
 use super::Snowflake;
 use ::chrono::{DateTime, Utc};
 #[cfg(feature = "handler")]
 use log::{debug, error};
-#[cfg(feature = "handler")]
-use reqwest::{Client, StatusCode};
-
-// ===== USEFUL MACROS =====
-macro_rules! expect_successful_api_response {
-    ($response:ident, $succret:expr) => {
-        match $response {
-            Err(e) => {
-                debug!("Discord API request failed: {:#?}", e);
-                Err(HttpError {
-                    code: 0,
-                    message: format!("{:#?}", e),
-                })
-            }
-            Ok(r) => {
-                let st = r.status();
-                if !st.is_success() {
-                    let e = format!("{:#?}", r.text().await);
-                    debug!("Discord API returned an error: {:#?}", e);
-                    Err(HttpError {
-                        code: st.as_u16(),
-                        message: e,
-                    })
-                } else {
-                    $succret
-                }
-            }
-        }
-    };
-}
-
-macro_rules! expect_specific_api_response {
-    ($response:ident, $expres:expr, $succret:expr) => {
-        match $response {
-            Err(e) => {
-                debug!("Discord API request failed: {:#?}", e);
-
-                Err(HttpError {
-                    code: 0,
-                    message: format!("{:#?}", e),
-                })
-            }
-            Ok(r) => {
-                let st = r.status();
-                if st != $expres {
-                    let e = format!("{:#?}", r.text().await);
-                    debug!("Discord API returned an error: {:#?}", e);
-                    Err(HttpError {
-                        code: st.as_u16(),
-                        message: e,
-                    })
-                } else {
-                    $succret
-                }
-            }
-        }
-    };
-}
+#[cfg(any(feature = "handler", feature = "extended-handler"))]
+use reqwest::{Client, StatusCode, };
 
 // ======================
 
-#[cfg(feature = "handler")]
+#[cfg(any(feature = "handler", feature = "extended-handler"))]
 #[derive(Clone)]
 ///
 pub struct Context {
     client: Client,
-
     /// The [`Interaction`] sent by Discord.
     pub interaction: Interaction,
 }
-
 #[serde_as]
 #[derive(Clone, Serialize, Deserialize, Debug)]
 /// The base Interaction structure. When Interactions are received, this structure is wrapped inside a [`Context`]
@@ -119,116 +68,11 @@ pub struct Interaction {
     pub version: Option<i8>,
 }
 
-#[cfg(feature = "handler")]
-impl Context {
-    /// Creates a new [`Context`]
-    pub fn new(c: Client, i: Interaction) -> Self {
-        Self {
-            client: c,
-            interaction: i,
-        }
-    }
 
-    /// Respond to an Interaction
-    ///
-    /// This returns an [`InteractionResponseBuilder`] which you can use to build an [`InteractionResponse`]
-    ///
-    /// # Example
-    /// ```ignore
-    /// let response = ctx.respond()
-    ///                   .content("Example message")
-    ///                   .tts(true)
-    ///                   .finish();
-    /// ```
-    pub fn respond(&self) -> InteractionResponseBuilder {
-        InteractionResponseBuilder::default()
-    }
-
-    /// Edit the original interaction response
-    ///
-    /// This takes an [`WebhookMessage`]. You can convert an [`InteractionResponse`] using [`WebhookMessage::from`].
-    pub async fn edit_original(&self, new_content: &WebhookMessage) -> Result<(), HttpError> {
-        let url = format!(
-            "{}/webhooks/{:?}/{}/messages/@original",
-            crate::BASE_URL,
-            self.interaction.application_id.unwrap(),
-            self.interaction.token.as_ref().unwrap().to_string()
-        );
-        let c = self.client.patch(&url).json(new_content).send().await;
-
-        expect_successful_api_response!(c, Ok(()))
-    }
-
-    /// Delete the original interaction response
-    pub async fn delete_original(&self) -> Result<(), HttpError> {
-        let url = format!(
-            "{}/webhooks/{:?}/{}/messages/@original",
-            crate::BASE_URL,
-            self.interaction.application_id.unwrap(),
-            self.interaction.token.as_ref().unwrap().to_string()
-        );
-        let c = self.client.delete(&url).send().await;
-
-        expect_specific_api_response!(c, StatusCode::NO_CONTENT, Ok(()))
-    }
-
-    /// Create a follow-up message
-    pub async fn create_followup(
-        &self,
-        content: &WebhookMessage,
-    ) -> Result<FollowupMessage, HttpError> {
-        let url = format!(
-            "{}/webhooks/{:?}/{}?wait=true",
-            crate::BASE_URL,
-            self.interaction.application_id.unwrap(),
-            self.interaction.token.as_ref().unwrap().to_string()
-        );
-
-        let c = self.client.post(&url).json(content).send().await;
-
-        match c {
-            Err(e) => {
-                debug!("Discord API request failed: {:#?}", e);
-                Err(HttpError {
-                    code: 0,
-                    message: format!("{:#?}", e),
-                })
-            }
-            Ok(r) => {
-                let st = r.status();
-                if !st.is_success() {
-                    let e = format!("{:#?}", r.text().await);
-                    debug!("Discord API returned an error: {:#?}", e);
-                    Err(HttpError {
-                        code: st.as_u16(),
-                        message: e,
-                    })
-                } else {
-                    let a: Result<FollowupMessage, serde_json::Error> =
-                        serde_json::from_str(&r.text().await.unwrap());
-
-                    match a {
-                        Err(e) => {
-                            debug!("Failed to decode response: {:#?}", e);
-                            Err(HttpError {
-                                code: 500,
-                                message: format!("{:?}", e),
-                            })
-                        }
-                        Ok(mut f) => {
-                            f.interaction_token =
-                                self.interaction.token.as_ref().unwrap().to_string();
-                            Ok(f)
-                        }
-                    }
-                }
-            }
-        }
-    }
-}
 
 #[derive(Clone, Serialize_repr, Deserialize_repr, PartialEq, Debug)]
 #[repr(u8)]
+#[non_exhaustive]
 /// Represents the type of interaction that comes in.
 pub enum InteractionType {
     /// Discord requested a ping
@@ -452,7 +296,7 @@ pub struct WebhookMessage {
     pub payload_json: Option<String>,
     allowed_mentions: Option<AllowedMentions>,
 }
-
+#[cfg(feature = "handler")]
 impl WebhookMessage{
     /// Add text to this WebhookMessage
     pub fn content(mut self, content: impl ToString) -> Self{
@@ -537,7 +381,7 @@ impl MessageReference {
         self.channel_id
     }
 }
-
+#[cfg(feature = "handler")]
 #[serde_as]
 #[skip_serializing_none]
 #[derive(Clone, Serialize, Deserialize, Debug)]
@@ -570,7 +414,7 @@ pub struct FollowupMessage {
     #[serde(skip)]
     client: Client,
 }
-
+#[cfg(feature = "handler")]
 /// Getter functions
 impl FollowupMessage {
     /// Get the ID of this follow up
@@ -625,6 +469,7 @@ impl FollowupMessage {
     }
 }
 
+#[cfg(feature = "handler")]
 /// 'Do' functions
 impl FollowupMessage {
     /// Edit this followup message
@@ -680,3 +525,142 @@ impl FollowupMessage {
         }
     }
 }
+
+#[cfg(feature = "handler")]
+impl Context {
+    /// Creates a new [`Context`]
+    pub fn new(c: Client, i: Interaction) -> Self {
+        Self {
+            client: c,
+            interaction: i,
+        }
+    }
+
+    /// Respond to an Interaction
+    ///
+    /// This returns an [`InteractionResponseBuilder`] which you can use to build an [`InteractionResponse`]
+    ///
+    /// # Example
+    /// ```ignore
+    /// let response = ctx.respond()
+    ///                   .content("Example message")
+    ///                   .tts(true)
+    ///                   .finish();
+    /// ```
+    pub fn respond(&self) -> InteractionResponseBuilder {
+        InteractionResponseBuilder::default()
+    }
+
+    /// Edit the original interaction response
+    ///
+    /// This takes an [`WebhookMessage`]. You can convert an [`InteractionResponse`] using [`WebhookMessage::from`].
+    pub async fn edit_original(&self, new_content: &WebhookMessage) -> Result<(), HttpError> {
+        let url = format!(
+            "{}/webhooks/{:?}/{}/messages/@original",
+            crate::BASE_URL,
+            self.interaction.application_id.unwrap(),
+            self.interaction.token.as_ref().unwrap().to_string()
+        );
+        let c = self.client.patch(&url).json(new_content).send().await;
+
+        expect_successful_api_response!(c, Ok(()))
+    }
+
+    /// Delete the original interaction response
+    pub async fn delete_original(&self) -> Result<(), HttpError> {
+        let url = format!(
+            "{}/webhooks/{:?}/{}/messages/@original",
+            crate::BASE_URL,
+            self.interaction.application_id.unwrap(),
+            self.interaction.token.as_ref().unwrap().to_string()
+        );
+        let c = self.client.delete(&url).send().await;
+
+        expect_specific_api_response!(c, StatusCode::NO_CONTENT, Ok(()))
+    }
+
+    /// Create a follow-up message
+    pub async fn create_followup(
+        &self,
+        content: &WebhookMessage,
+    ) -> Result<FollowupMessage, HttpError> {
+        let url = format!(
+            "{}/webhooks/{:?}/{}?wait=true",
+            crate::BASE_URL,
+            self.interaction.application_id.unwrap(),
+            self.interaction.token.as_ref().unwrap().to_string()
+        );
+
+        let c = self.client.post(&url).json(content).send().await;
+
+        match c {
+            Err(e) => {
+                debug!("Discord API request failed: {:#?}", e);
+                Err(HttpError {
+                    code: 0,
+                    message: format!("{:#?}", e),
+                })
+            }
+            Ok(r) => {
+                let st = r.status();
+                if !st.is_success() {
+                    let e = format!("{:#?}", r.text().await);
+                    debug!("Discord API returned an error: {:#?}", e);
+                    Err(HttpError {
+                        code: st.as_u16(),
+                        message: e,
+                    })
+                } else {
+                    let a: Result<FollowupMessage, serde_json::Error> =
+                        serde_json::from_str(&r.text().await.unwrap());
+
+                    match a {
+                        Err(e) => {
+                            debug!("Failed to decode response: {:#?}", e);
+                            Err(HttpError {
+                                code: 500,
+                                message: format!("{:?}", e),
+                            })
+                        }
+                        Ok(mut f) => {
+                            f.interaction_token =
+                                self.interaction.token.as_ref().unwrap().to_string();
+                            Ok(f)
+                        }
+                    }
+                }
+            }
+        }
+    }
+}
+
+#[cfg(feature="extended-handler")]
+/// Getter functions
+impl Context{
+    /// Get a [`Guild`] from an ID
+    pub async fn get_guild<I: Into<Snowflake>>(&self, id: I) -> Result<Guild, HttpError>{
+        let url = format!(
+            "{}/guilds/{:?}?with_counts=true",
+            crate::BASE_URL,
+            id.into());
+
+        let r = self.client.get(&url)
+                    .send()
+                    .await;
+        expect_successful_api_response_and_return!(r, Guild, g, Ok(g))
+    }
+
+    /// Get a [`Member`] from a [`Guild`]
+    pub async fn get_guild_member(&self, guild_id: impl Into<Snowflake>, user_id: impl Into<Snowflake>) -> Result<Member, HttpError>{
+        let url = format!(
+            "{}/guilds/{:?}/members/{:?}",
+            crate::BASE_URL,
+            guild_id.into(),
+            user_id.into());
+
+        let r = self.client.get(&url)
+                    .send()
+                    .await;
+        expect_successful_api_response_and_return!(r, Member, m, Ok(m))
+    }
+}
\ No newline at end of file
